
// TestMouse.java
// Andrew Davison, August 2012, ad@fivedots.coe.psu.ac.th

/*  Report button presses, (x,y) moves, and wheel rotations for
    a given mouse controller. The controller is specified by its
    controller index, which you can obtain by calling MiceReporter.

    On Windows, JInput can use DirectX or raw input (the default) for
    detecting mice. Raw input, unlike DirectX, supports multiple mice, but only
    when the application's windows has focus. For that reason, TestMouse creates
    a JFrame.
   
    Usage pattern:
       run TestMouse <controller index>
    e.g.
       run TestMouse 2
    
    The reported data is sent to the command window; the empty JFrame is only
    used to close the application.
*/

import javax.swing.*;
import java.awt.*;
import java.io.*;


public class TestMouse  extends JFrame 
{
  private static final int DELAY = 40;  // ms  (update interval)

  private MouseController mc;


  public TestMouse(int index)
  {
    super("TestMouse");

    mc = new MouseController(index);

    setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
    setSize(200, 200);  
    setVisible(true);

    new Thread(new Runnable() {
      public void run() {
        update(mc);    // keep polling the component
      }
    }).start();
  }  // end of TestMouse()



  private void update(MouseController mc)
  /* Repeatedly update the MouseController, which polls its
     components and prints it their values. Sleep for
     DELAY ms between each update.
  */
  {
    while (true) {
      if (!mc.update()) {
        System.out.println("Mouse Controller no longer valid");
        System.exit(0);
      }

      try {
        Thread.sleep(DELAY);      // wait a while
      } 
      catch (Exception ex) {}
    }
  }  // end of update()


  // ---------------------------------------------------------


  public static void main(String[] args)
  {
    if (args.length < 1) {
      System.out.println("Usage: TestMouse <index>");
      System.exit(0);
    }

    int index = 0;
    try {
      index = Integer.parseInt(args[0]);
    }
    catch (NumberFormatException e) 
    {  System.out.println("Incorrect index format; using 0");  }

    new TestMouse(index);
  } // end of main()

} // end of TestMouse class
