
// Multitouch.java
// Andrew Davison, August 2012, ad@fivedots.coe.psu.ac.th

/* A full-screen undecorated window appears with randomly placed images. 
   The pics can be grabbed, rotated, and enlarged by using two mice (or a 
   mouse and trackpad) as 'finger tips'. 

   Pressing on an image allows it to be moved. It's possible to move
   two images at once by pressing the finger tips on different images.

   Pressing both finger tips on the same image allows it to be enlarged
   (by dragging apart the finger tips), or shrunk back to its 
   original size.

   Pressing one finger tip on the window, and the other on an image
   allows the image to be rotated around the first 'pivot' tip.
   The image also rotates around its center.

   Type ESC, q, ctrl-c to exit the game.
   The app. hides the cursor, showing only the two finger tips.

   The two finger tips are implemented as JInput controllers, which
   are initilized with the IDs for the mice (or mouse and trackpad).
   These IDs can be found by calling the MiceReporter app.
*/

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.awt.image.*;



public class Multitouch extends JFrame 
{

  private MultitouchPanel mp;


  public Multitouch()
  {
    super("Multitouch");

    mp = new MultitouchPanel();
	Container c = getContentPane();
	c.add(mp);

    addWindowListener( new WindowAdapter() {
      public void windowClosing(WindowEvent e)
      { mp.closeDown();  }    // not likely to be used, since frame is undecorated
    });

    hideCursor(c);
    setUndecorated(true);
    pack();    // the panel makes itself full-screen size
    setResizable(false);
    setVisible(true);
  }  // end of Multitouch()


  private void hideCursor(Container c)
  {
    // create a transparent 16 x 16 pixel cursor image
    BufferedImage cursorIm = new BufferedImage(16, 16, BufferedImage.TYPE_INT_ARGB);

    // create a new blank cursor
    Cursor blankCursor = Toolkit.getDefaultToolkit().createCustomCursor(
                                    cursorIm, new Point(0, 0), "blank cursor");

    // assign the blank cursor to the JFrame
    c.setCursor(blankCursor);
  }  // end of hideCursor()


   // ---------------------------------------------------

   public static void main(String args[])
   {  new Multitouch(); }

} // end of Multitouch

